import { HazelReader, HazelWriter } from "@skeldjs/util";
import { SystemType } from "@skeldjs/constant";
import { RepairSystemMessage } from "@skeldjs/protocol";
import { ExtractEventTypes } from "@skeldjs/events";
import { InnerShipStatus } from "../objects";
import { SystemStatus } from "./SystemStatus";
import { PlayerData } from "../PlayerData";
import { ElectricalSwitchFlipEvent } from "../events";
import { SystemStatusEvents } from "./events";
import { Hostable } from "../Hostable";
declare type SwitchSetup = [boolean, boolean, boolean, boolean, boolean];
export interface SwitchSystemData {
    expected: SwitchSetup;
    actual: SwitchSetup;
    brightness: number;
}
export declare type SwitchSystemEvents<RoomType extends Hostable = Hostable> = SystemStatusEvents<RoomType> & ExtractEventTypes<[
    ElectricalSwitchFlipEvent<RoomType>
]>;
/**
 * Represents a system responsible for handling switches in Electrical.
 *
 * See {@link SwitchSystemEvents} for events to listen to.
 */
export declare class SwitchSystem<RoomType extends Hostable = Hostable> extends SystemStatus<SwitchSystemData, SwitchSystemEvents, RoomType> implements SwitchSystemData {
    /**
     * The switch states that are expected.
     */
    expected: SwitchSetup;
    /**
     * The current switch states.
     */
    actual: SwitchSetup;
    /**
     * The brightness of lights.
     */
    brightness: number;
    private timer;
    get sabotaged(): boolean;
    constructor(ship: InnerShipStatus<RoomType>, systemType: SystemType, data?: HazelReader | SwitchSystemData);
    Deserialize(reader: HazelReader, spawn: boolean): void;
    Serialize(writer: HazelWriter, spawn: boolean): void;
    HandleSabotage(player: PlayerData<RoomType> | undefined, rpc: RepairSystemMessage | undefined): Promise<void>;
    private _setSwitch;
    /**
     * Set the value of a switch as flipped or not flipped
     * @param num The ID of the switch to flip.
     * @param value Whether the switch is flipped.
     * @example
     *```typescript
     * // Randomise each switch.
     * for (let i = 0; i < 5; i++) {
     *   electrical.setSwitch(i, Math.random() > 0.5);
     * }
     * ```
     */
    setSwitch(num: number, value: boolean): Promise<void>;
    /**
     * Invert the position of a switch.
     * @param num The ID of the switch to invert.
     * @example
     *```typescript
     * // Invert the position of each switch.
     * for (let i = 0; i < 5; i++) {
     *   electrical.flip(i);
     * }
     * ```
     */
    flip(num: number): Promise<void>;
    private _repair;
    repair(): Promise<void>;
    HandleRepair(player: PlayerData<RoomType> | undefined, amount: number, rpc: RepairSystemMessage | undefined): Promise<void>;
    Detoriorate(delta: number): void;
    /**
     * Read the value of each switch from a byte.
     * @param byte The byte to read from.
     * @returns An array of the value of each switch.
     * @example
     *```typescript
     * console.log(readSwitches(0x5));
     * // [ true, false, true, false, false ]
     * ```
     */
    static readSwitches(byte: number): SwitchSetup;
    /**
     * Write the value of each switch to a byte.
     * @param switches An array of the value of each switch.
     * @returns The byte representation of the switches.
     * @example
     *```typescript
     * console.log(writeSwitches([ false, true, false, false, true ]));
     * // 0x12 (18)
     * ```
     */
    static writeSwitches(switches: SwitchSetup): number;
}
export {};
//# sourceMappingURL=SwitchSystem.d.ts.map